<?php

namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\ApontamentoService;
use FM\Traits\TResponse;

class ApontamentoController extends FMCrud
{

    use TResponse;

    protected $ApontamentoService;

    public function __construct($crudService, $environment, ApontamentoService $ApontamentoService)
    {
        parent::__construct($crudService, $environment);
        $this->ApontamentoService = $ApontamentoService;
    }

    public function getDadosApontamento()
    {
        try {
            $data = $this->ApontamentoService->getDadosApontamento();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDadosApontamentoInserido(Request $request)
    {
        try {
            $data = $this->ApontamentoService->getDadosApontamentoInserido($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function buscaRegistrosHora(DTO\Request $request, DTO\Response $response)
    {
        $parametro = $request->getParameters();

        $pesquisaRegistro = $this->ApontamentoService->buscaRegistrosHora($parametro);

        $dtsVal = new DataSet('dados', $pesquisaRegistro);
        $response->addDataSet($dtsVal);
    }

    public function insertNovoApontamento(DTO\Request $request, DTO\Response $response)
    {
        $parametro = $request->getParameters();
        $insAp = $this->ApontamentoService->insertNovoApontamento($parametro);
        $dtsVal = new DataSet('dados', array('retorno' => $insAp));
        $response->addDataSet($dtsVal);
    }

    public function deleteRegistroHoras(DTO\Request $request, DTO\Response $response)
    {
        $parametro = $request->getParameters();
        $delete = $this->ApontamentoService->deleteRegistroHoras($parametro);
        $dtsVal = new DataSet('dados', array('retorno' => $delete));
        $response->addDataSet($dtsVal);
    }

    public function apurarHoras(DTO\Request $request, DTO\Response $response)
    {
        $parametro = $request->getParameters();

        $retornoApuracao = $this->ApontamentoService->apurarHoras($parametro);
        $dtsVal = new DataSet('dados', array('retorno' => $retornoApuracao));
        $response->addDataSet($dtsVal);
    }

    public function getDadosDocEObservacoes(DTO\Request $request, DTO\Response $response)
    {
        $parametro = $request->getParameters();
        $retornoObservacoes = $this->ApontamentoService->getDadosDocEObservacoes($parametro);
        $dtsVal = new DataSet('dados', $retornoObservacoes);
        $response->addDataSet($dtsVal);
    }

    public function getIntervaloTrabalho(Request $request)
    {
        try {
            $data = $this->ApontamentoService->getIntervaloTrabalho($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function setNewRegister(DTO\Request $request, DTO\Response $response)
    {

        $parametros = $request->getParameters();
        // debugApi([$parametros]);

        $variavel = $this->ApontamentoService->setNewRegister($parametros);
        $dtsVal = new DataSet('app', [$variavel]);
        $response->addDataSet($dtsVal);
    }

    public function typeRegister(DTO\Request $request, DTO\Response $response)
    {
        $parametros = $request->getParameters();

        $variavel = $this->ApontamentoService->typeRegister($parametros);
        $dtsVal = new DataSet('types', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function optionLunch(DTO\Request $request, DTO\Response $response)
    {
        $parametros = $request->getParameters();

        $variavel = $this->ApontamentoService->optionLunch($parametros);
        // debugApi([$variavel]);
        $dtsVal = new DataSet('option', [$variavel]);
        $response->addDataSet($dtsVal);
    }

    public function cardsRegisters(DTO\Request $request, DTO\Response $response)
    {
        $parametros = $request->getParameters();

        $variavel = $this->ApontamentoService->cardsRegisters($parametros);
        $dtsVal = new DataSet('cards', $variavel);
        $response->addDataSet($dtsVal);
    }

    public function setAbsence(DTO\Request $request, DTO\Response $response)
    {
        $parametros = $request->getParameters();

        $variavel = $this->ApontamentoService->setAbsence($parametros);
        $dtsVal = new DataSet('absence', [$variavel]);
        $response->addDataSet($dtsVal);
    }

    public function setLastAppointment(DTO\Request $request, DTO\Response $response)
    {

        $parametros = $request->getParameters();
        // debugApi([$parametros]);

        $variavel = $this->ApontamentoService->setLastAppointment($parametros);
        $dtsVal = new DataSet('last', [$variavel]);
        $response->addDataSet($dtsVal);
    }
}
